summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kfiletreebranch.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kfile/kfiletreebranch.h')
-rw-r--r--kio/kfile/kfiletreebranch.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kfile/kfiletreebranch.h b/kio/kfile/kfiletreebranch.h
index 03976a8d7..30f5cf47c 100644
--- a/kio/kfile/kfiletreebranch.h
+++ b/kio/kfile/kfiletreebranch.h
@@ -166,9 +166,9 @@ protected:
public:
/**
* tqfind the according KFileTreeViewItem by an url
*/
- virtual KFileTreeViewItem *tqfindTVIByURL( const KURL& );
+ virtual KFileTreeViewItem *findTVIByURL( const KURL& );
signals:
/**
@@ -213,7 +213,7 @@ private:
KURL::List m_openChildrenURLs;
/* The next two members are used for caching purposes in tqfindTVIByURL. */
KURL m_lastFoundURL;
KFileTreeViewItem *m_lastFoundItem;
@@ -166,9 +166,9 @@ protected:
public:
/**
- * tqfind the according KFileTreeViewItem by an url
+ * find the according KFileTreeViewItem by an url
*/
@@ -213,7 +213,7 @@ private:
KURL::List m_openChildrenURLs;
- /* The next two members are used for caching purposes in tqfindTVIByURL. */
+ /* The next two members are used for caching purposes in findTVIByURL. */
KURL m_lastFoundURL;
KFileTreeViewItem *m_lastFoundItem;